<?xml version="1.0" encoding="iso-8859-1"?>
<!--
  Copyright 2003-2005 by Alexander Bartolich.
  This is free software; you can redistribute it and/or modify it under
  the terms of the GPL as published by the Free Software Foundation;
  either version 2 of the License, or (at your option) any later version.
-->
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:stext="http://nwalsh.com/xslt/ext/com.nwalsh.saxon.TextFactory"
  xmlns:xtext="com.nwalsh.xalan.Text"
  xmlns:jtxt="http://www.jclark.com/xt/java/TextDocument"
  exclude-result-prefixes="exsl jtxt stext xtext"
  extension-element-prefixes="exsl jtxt stext xtext"
>
<xsl:include href="param.xsl"/>

<!--
 ! toc.filename - either index.html or toc.html
 ! -->
<xsl:variable name="toc.filename">
  <xsl:call-template name="id-to-filename">
    <xsl:with-param name="the.id">
      <xsl:if test="$toc.on.separate.page">
        <xsl:value-of select="$toc.id"/>
      </xsl:if>
      <xsl:if test="not($toc.on.separate.page)">
        <xsl:value-of select="/*/@id"/>
      </xsl:if>
    </xsl:with-param>
  </xsl:call-template>
</xsl:variable>

<!--
 ! id-to-filename
 ! -->
<xsl:template name="id-to-filename">
  <xsl:param name="the.id" select="/*/@id"/>
  <xsl:if test="string-length($the.id) &gt; 0">
    <xsl:value-of select="concat($the.id, '.html')"/>
  </xsl:if>
</xsl:template>

<!--
 ! id-to-href
 ! -->
<xsl:template name="id-to-href">
  <xsl:param name="the.id" select="@linkend"/>
  <xsl:param name="base.node" select="ancestor-or-self::sect1"/>

  <xsl:variable name="top" select="id($the.id)/ancestor-or-self::sect1"/>

  <xsl:variable name="file">
    <xsl:if test="0 = count($base.node) or $top != $base.node">
      <xsl:call-template name="id-to-filename">
	<xsl:with-param name="the.id" select="$top/@id"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:variable>

  <xsl:variable name="anchor">
    <xsl:if test="$the.id != $top/@id">
      <xsl:value-of select="concat('#', $the.id)"/>
    </xsl:if>
  </xsl:variable>

  <xsl:value-of select="concat($file, $anchor)"/>

</xsl:template>

<!--
 ! id-to-label
 ! -->
<xsl:template mode="id-to-label" match="node()">
  <xsl:choose>
    <xsl:when test="@xreflabel">
      <xsl:value-of select="@xreflabel"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:choose>
	<xsl:when test="title"><xsl:value-of select="title"/></xsl:when>
	<xsl:otherwise>
	  <xsl:apply-templates mode="id-to-label-sub" select="."/>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template mode="id-to-label-sub" match="anchor">
  <xsl:value-of select="following::*/title"/>
</xsl:template>

<xsl:template mode="id-to-label-sub" match="question">
  <xsl:value-of select="normalize-space(simpara[1])"/>
</xsl:template>

<!--
 ! place-anchor
 ! -->
<xsl:template name="place-anchor">
  <xsl:param name="name" select="@id"/>

  <xsl:if test="string-length($name) &gt; 0">
    <a name="{$name}"/>
  </xsl:if>
</xsl:template>

<!--
 ! next-chapter-id
 ! -->
<xsl:template name="next-chapter-id">
  <xsl:param name="create-separate-toc-page" select="false()"/>

  <xsl:choose><xsl:when test="ancestor-or-self::sect1">

    <!-- this is a regular page -->
    <xsl:value-of
      select="ancestor-or-self::sect1/following-sibling::sect1[1]/@id"/>

  </xsl:when><xsl:when test="
    $create-separate-toc-page
    or (not($toc.on.separate.page))
  ">
    <!-- this is either index.html or toc.html -->
    <xsl:value-of select="/*/sect1/@id"/>

  </xsl:when><xsl:otherwise>

    <!-- this index.html followed by toc.html -->
    <xsl:value-of select="$toc.id"/>
    
  </xsl:otherwise></xsl:choose>
</xsl:template>

<!--
 ! prev-chapter-id
 ! -->
<xsl:template name="prev-chapter-id">
  <xsl:param name="create-separate-toc-page" select="false()"/>
  <xsl:variable name="prev"
    select="ancestor-or-self::sect1/preceding-sibling::sect1[1]/@id"/>

  <xsl:choose><xsl:when test="$prev">

    <!-- this is a regular page but not chapter1.html -->
    <xsl:value-of select="$prev"/>

  </xsl:when><xsl:when test="
    $create-separate-toc-page
    or (ancestor-or-self::sect1 and not($toc.on.separate.page))
  ">
    <!-- this is either toc.html or chapter1.html following index.html -->
    <xsl:value-of select="/*/@id"/>

  </xsl:when><xsl:when test="ancestor-or-self::sect1">

    <!-- this is chapter1.html following toc.html -->
    <xsl:value-of select="$toc.id"/>

  </xsl:when></xsl:choose>
</xsl:template>

<!--
 ! navigation-button
 ! -->
<xsl:template name="navigation-button">
  <xsl:param name="title"/>
  <xsl:param name="href"/>

  <td class="navigation" width="5%" align="center">
    <xsl:choose>
      <xsl:when test="string-length($title) &gt; 0">
	<a class="navigation" href="{$href}">
	  <xsl:value-of select="$title"/>
	</a>
      </xsl:when>
      <xsl:otherwise>&#xA0;</xsl:otherwise>
    </xsl:choose>
  </td>
</xsl:template>

<!--
 ! navigation-line
 ! -->
<xsl:template name="navigation-line">
  <xsl:param name="title" select="title"/>
  <xsl:param name="name" select="@id"/>
  <xsl:param name="validate" select="false()"/>
  <xsl:param name="create-separate-toc-page" select="false()"/>

  <xsl:param name="prev.href">
    <xsl:call-template name="id-to-filename">
      <xsl:with-param name="the.id">
	<xsl:call-template name="prev-chapter-id">
	  <xsl:with-param name="create-separate-toc-page"
	    select="$create-separate-toc-page"/>
	</xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:param>

  <xsl:param name="next.href">
    <xsl:call-template name="id-to-filename">
      <xsl:with-param name="the.id">
	<xsl:call-template name="next-chapter-id">
	  <xsl:with-param name="create-separate-toc-page"
	    select="$create-separate-toc-page"/>
	</xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:param>

  <xsl:if test="string-length($name) &gt; 0">
    <a name="{$name}"/>
  </xsl:if>
  <table class="navigation" border="0" width="100%">
    <tr>
      <xsl:if test="string-length($prev.href) &gt; 0">
	<xsl:call-template name="navigation-button">
	  <xsl:with-param name="title" select="$navigation.prev"/>
	  <xsl:with-param name="href" select="$prev.href"/>
	</xsl:call-template>
      </xsl:if>

      <xsl:call-template name="navigation-button">
	<xsl:with-param name="title" select="$navigation.index"/>
	<xsl:with-param name="href" select="$toc.filename"/>
      </xsl:call-template>

      <td class="navigation" align="center"><b class="navigation">
	<xsl:value-of select="$title"/>
      </b></td>

      <xsl:if test="$validate != 0">
	<xsl:call-template name="navigation-button">
	  <xsl:with-param name="title" select="$navigation.validate"/>
	  <xsl:with-param name="href" select="$validate.href"/>
	</xsl:call-template>
      </xsl:if>

      <xsl:call-template name="navigation-button">
	<xsl:with-param name="title" select="$navigation.top"/>
	<xsl:with-param name="href" select="'#top'"/>
      </xsl:call-template>

      <xsl:if test="string-length($next.href) &gt; 0">
	<xsl:call-template name="navigation-button">
	  <xsl:with-param name="title" select="$navigation.next"/>
	  <xsl:with-param name="href" select="$next.href"/>
	</xsl:call-template>
      </xsl:if>

    </tr>
  </table>
</xsl:template>

<!--
 ! index-sub-title
 ! -->
<xsl:template name="index-sub-title">
  <xsl:param name="create-separate-toc-page" select="false()"/>

  <xsl:choose>
    <xsl:when test="current() = /* and not($create-separate-toc-page)">
      <xsl:value-of select="$index.sub.title"/>
    </xsl:when>
    <xsl:when test="current() = /* and $create-separate-toc-page">
      <xsl:value-of select="$toc.title"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="title"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!--
 ! one-html-file
 ! -->
<xsl:template name="one-html-file">
  <xsl:param name="the.id" select="@id"/>
  <xsl:param name="create-separate-toc-page" select="false()"/>
  <xsl:param name="nodes" select="."/>

  <xsl:variable name="file">
    <xsl:call-template name="id-to-filename">
      <xsl:with-param name="the.id" select="$the.id"/>
    </xsl:call-template>
  </xsl:variable>

  <exsl:document method="xml" href="{$file}"
    encoding="{$output.encoding}" indent="yes"
    doctype-system="{$doctype-system}"
    doctype-public="{$doctype-public}">
  <xsl:comment>
Generated by at.linux.xsl. Do not modify.
</xsl:comment>
  <html>
    <head>
      <title><xsl:value-of select="title"/></title>
      <xsl:copy-of select="$html.head"/>
      <link href="{$toc.filename}" rel="contents"/>
    </head>
    <body>
      <xsl:choose><xsl:when test="$index.picture and $the.id = /*/@id">

	<div align="center"><a name="top"></a>
	<table><tr valign="middle"><td>
	  <h1><xsl:value-of select="/*/title"/></h1>
	  <h2><xsl:call-template name="index-sub-title"/></h2>
	</td><td>
	  <img src="{$index.picture}" alt="[ Logo ]"/>
	</td></tr></table>
	</div>

      </xsl:when><xsl:otherwise>

	<div align="center">
	  <h1><a name="top"/><xsl:value-of select="/*/title"/></h1>
	</div>
	<div align="center">
	  <h2>
	    <xsl:call-template name="index-sub-title">
	      <xsl:with-param name="create-separate-toc-page"
		select="$create-separate-toc-page"/>
	    </xsl:call-template>
	  </h2>
	</div>
	<br/>
	<br/>

      </xsl:otherwise></xsl:choose>

      <xsl:if test="$create-separate-toc-page">
	<xsl:apply-templates mode="toc" select="$nodes">
	  <xsl:with-param name="create-separate-toc-page"
	    select="$create-separate-toc-page"/>
	</xsl:apply-templates>
      </xsl:if>
      <xsl:if test="not($create-separate-toc-page)">
	<xsl:apply-templates select="$nodes"/>
      </xsl:if>

      <xsl:call-template name="navigation-line">
	<xsl:with-param name="title" select="$navigation.last"/>
	<xsl:with-param name="name" select="'bottom'"/>
	<xsl:with-param name="validate" select="true()"/>
	<xsl:with-param name="create-separate-toc-page"
	  select="$create-separate-toc-page"/>
      </xsl:call-template>
    </body>
  </html>
  </exsl:document>
</xsl:template>

<!--
 !
 ! -->
<xsl:template match="/*/sect1" mode="index">
  <xsl:call-template name="one-html-file"/>
</xsl:template>

<!--
 !
 ! -->
<xsl:template match="/*" mode="index">
   <!-- index.html -->
  <xsl:call-template name="one-html-file"/>

  <!-- toc.html -->
  <xsl:if test="$toc.on.separate.page">
    <xsl:call-template name="one-html-file">
      <xsl:with-param name="the.id" select="$toc.id"/>
      <xsl:with-param name="create-separate-toc-page" select="true()"/>
      <xsl:with-param name="nodes" select="."/>
    </xsl:call-template>
  </xsl:if>

   <!-- chapterX.html -->
  <xsl:apply-templates select="sect1" mode="index"/>
</xsl:template>

<!--
 !
 ! -->
<xsl:template match="/">
  <xsl:apply-templates mode="index"/>
</xsl:template>

<!--
 ! link-from-toc
 ! -->
<xsl:template name="link-from-toc">
  <xsl:param name="toc.base.node"/>
  <xsl:param name="title" select="title"/>
  <xsl:param name="the.id" select="@id"/>

  <xsl:variable name="href">
    <xsl:call-template name="id-to-href">
      <xsl:with-param name="the.id" select="$the.id"/>
      <xsl:with-param name="base.node" select="$toc.base.node"/>
    </xsl:call-template>
  </xsl:variable>

  <a href="{$href}"><xsl:value-of select="normalize-space($title)"/></a>
</xsl:template>

<!--
 !
 ! -->
<xsl:template mode="sub-toc-on-page" match="/*/sect1">
  <xsl:param name="toc.base.node"/>
  <li>
    <a name="{@id}"/>
    <xsl:call-template name="link-from-toc">
      <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
    </xsl:call-template>
    <xsl:if test="count(sect2|qandaset)">
      <ul type="{$toc.sect2.ul}">
	<xsl:apply-templates mode="sub-toc-on-page" select="sect2|qandaset">
	  <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
	</xsl:apply-templates>
      </ul>
    </xsl:if>
    <br/>
  </li>
</xsl:template>

<!--
 !
 ! -->
<xsl:template mode="sub-toc-toc-on-page" match="/*/sect1">
  <xsl:param name="toc.base.node"/>
  <li>
    <a href="{concat('#', @id)}">
      <xsl:value-of select="normalize-space(title)"/>
    </a>
  </li>
</xsl:template>

<!--
 !
 ! -->
<xsl:template mode="sub-toc-on-page" match="/*/sect1/qandaset">
  <xsl:param name="toc.base.node"/>
  <xsl:apply-templates mode="sub-toc-on-page" select="qandadiv|qandaentry/question">
    <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
  </xsl:apply-templates>
</xsl:template>

<!--
 !
 ! -->
<xsl:template mode="sub-toc-on-page" match="/*/sect1/sect2|/*/sect1/qandaset/qandadiv">
  <xsl:param name="toc.base.node"/>
  <li>
    <xsl:call-template name="link-from-toc">
      <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
    </xsl:call-template>
    <xsl:if test="count(sect3|qandaentry/question)">
      <ul type="{$toc.sect2.ul}">
	<xsl:apply-templates mode="sub-toc-on-page"
	  select="sect3|qandaentry/question">
	  <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
	</xsl:apply-templates>
      </ul>
    </xsl:if>
    </li>
</xsl:template>

<xsl:template mode="sub-toc-on-page" match="/*/sect1/sect2/sect3">
  <xsl:param name="toc.base.node"/>
  <li>
    <xsl:call-template name="link-from-toc">
      <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
      <xsl:with-param name="title" select="title"/>
    </xsl:call-template>
  </li>
</xsl:template>

<!--
 !
 ! -->
<xsl:template mode="sub-toc-on-page"
  match="qandaentry/question">
  <xsl:param name="toc.base.node"/>
  <li>
    <xsl:call-template name="link-from-toc">
      <xsl:with-param name="toc.base.node" select="$toc.base.node"/>
      <xsl:with-param name="title" select="normalize-space(simpara[1])"/>
    </xsl:call-template>
  </li>
</xsl:template>

<xsl:template name="block">
  <xsl:param name="class"/>
  <xsl:apply-templates
    select="anchor|blockquote|formalpara|informaltable|itemizedlist|
      orderedlist|qandaset|para|programlisting|screen|simpara|
      simplelist|table|variablelist
  ">
    <xsl:with-param name="class" select="$class"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="/*">
  <xsl:call-template name="block"/>

  <xsl:if test="not($toc.on.separate.page)">
    <xsl:apply-templates select="." mode="toc"/>
  </xsl:if>
</xsl:template>

<!--
 ! called by either match="/*" or name="one-html-file"
 -->
<xsl:template match="/*" mode="toc">
  <xsl:param name="create-separate-toc-page" select="false()"/>

  <xsl:call-template name="navigation-line">
    <xsl:with-param name="name" select="'index.index'"/>
    <xsl:with-param name="title" select="$toc.toc.title"/>
    <xsl:with-param name="create-separate-toc-page"
      select="$create-separate-toc-page"/>
  </xsl:call-template>
  <ol>
    <xsl:apply-templates mode="sub-toc-toc-on-page" select="sect1">
      <xsl:with-param name="toc.base.node" select="current()"/>
    </xsl:apply-templates>
  </ol>

  <xsl:call-template name="navigation-line">
    <xsl:with-param name="name" select="'index'"/>
    <xsl:with-param name="title" select="$toc.title"/>
    <xsl:with-param name="create-separate-toc-page"
      select="$create-separate-toc-page"/>
  </xsl:call-template>
  <ol>
    <xsl:apply-templates mode="sub-toc-on-page" select="sect1">
      <xsl:with-param name="toc.base.node" select="current()"/>
    </xsl:apply-templates>
  </ol>
</xsl:template>

<xsl:template match="/*/sect1">
  <xsl:call-template name="navigation-line">
    <xsl:with-param name="name" select="'toc'"/>
    <xsl:with-param name="title">
      <xsl:call-template name="title-of-chapter-toc"/>
    </xsl:with-param>
  </xsl:call-template>

  <ul type="{$toc.sect2.ul}">
    <xsl:apply-templates mode="sub-toc-on-page" select="sect2|qandaset">
      <xsl:with-param name="toc.base.node" select="current()"/>
    </xsl:apply-templates>
  </ul>

  <xsl:apply-templates select="sect2|qandaset"/>
</xsl:template>

<xsl:template match="/*/sect1/sect2">
  <xsl:choose>
    <xsl:when test="count(child::*) != count(child::title|child::sect3)">
      <xsl:call-template name="navigation-line"/>
      <xsl:call-template name="block"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="place-anchor"/>
      <xsl:apply-templates select="sect3"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="/*/sect1/sect2/sect3">
  <xsl:call-template name="navigation-line"/>
  <xsl:call-template name="block"/>
</xsl:template>

<xsl:template match="/*/sect1/qandaset">
  <xsl:call-template name="place-anchor"/>
  <xsl:apply-templates select="qandadiv|qandaentry"/>
</xsl:template>

<xsl:template match="qandadiv">
  <xsl:call-template name="place-anchor"/>
  <xsl:apply-templates select="qandaentry"/>
</xsl:template>

<xsl:template match="qandaentry">
  <xsl:call-template name="place-anchor"/>
  <xsl:apply-templates select="question"/>
  <xsl:apply-templates select="answer"/>
</xsl:template>

<xsl:template match="question">
  <xsl:call-template name="navigation-line">
    <xsl:with-param name="title" select="normalize-space(simpara[1])"/>
  </xsl:call-template>
  <xsl:call-template name="block">
    <xsl:with-param name="class" select="'questionTitle'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="answer">
  <xsl:call-template name="block"/>
</xsl:template>

<xsl:template match="formalpara">
  <xsl:choose>
    <xsl:when test="@role = 'toc'">
      <xsl:call-template name="navigation-line"/>
      <xsl:apply-templates select="para"/>
    </xsl:when>
    <xsl:otherwise>
      <p class="formalpara-title">
	<xsl:apply-templates select="title"/>
	<xsl:value-of select="$formalpara.sep"/>
      </p><p>
	<xsl:apply-templates select="para" mode="formalpara"/>
      </p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="para|simpara">
  <xsl:param name="class"/>
  <xsl:call-template name="place-anchor"/>
  <xsl:choose>
    <xsl:when test="$class != ''">
      <p class="{$class}">
	<xsl:apply-templates>
	  <xsl:with-param name="class" select="$class"/>
	</xsl:apply-templates>
      </p>
    </xsl:when>
    <xsl:otherwise>
      <p><xsl:apply-templates/></p>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="ulink">
  <a href="{@url}">
  <xsl:choose>
    <xsl:when test="string-length(.) = 0">
      <xsl:value-of select="@url"/>
    </xsl:when>
    <xsl:otherwise><xsl:apply-templates/></xsl:otherwise>
  </xsl:choose>
  </a>
</xsl:template>

<xsl:template match="anchor">
  <xsl:call-template name="place-anchor"/>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="link">
  <xsl:variable name="href">
    <xsl:call-template name="id-to-href"/>
  </xsl:variable>
  <a href="{$href}">
    <xsl:choose>
      <xsl:when test="string-length(.)">
        <xsl:value-of select="."/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates mode="id-to-label" select="id(@linkend)"/>
      </xsl:otherwise>
    </xsl:choose>
  </a>
</xsl:template>

<xsl:template match="xref">
  <xsl:variable name="href">
    <xsl:call-template name="id-to-href"/>
  </xsl:variable>
  <a href="{$href}">
    <xsl:apply-templates mode="id-to-label" select="id(@linkend)"/>
  </a>
</xsl:template>

<xsl:template match="programlisting">
  <xsl:apply-templates select="inlinemediaobject/imageobject/imagedata"/>
</xsl:template>

<xsl:template match="imagedata">
  <xsl:choose>
    <xsl:when test="@format != 'linespecific'">
      <xsl:message>Invalid format "<xsl:value-of
	select="@format"/>" in imagedata for fileref "<xsl:value-of
	select="@fileref"/>".</xsl:message>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="@fileref"/>
      <xsl:choose>
        <xsl:when test="element-available('stext:insertfile')">
	  <stext:insertfile href="{@fileref}"/>
	</xsl:when>
        <xsl:when test="element-available('xtext:insertfile')">
	  <xtext:insertfile href="{@fileref}"/>
	</xsl:when>
	<xsl:otherwise>
	  <a href="{@fileref}"><xsl:value-of select="@fileref"/></a>
	  <!--
	  <xsl:message terminate="yes"
	    >No insertfile extension available.</xsl:message>
	    -->
	</xsl:otherwise>

      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="command">
  <xsl:choose>
    <xsl:when test="ancestor::screen">
      <tt><b><xsl:apply-templates/></b></tt>
    </xsl:when>
    <xsl:otherwise>
      <tt><b><xsl:apply-templates/></b></tt>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="literal">
  <tt><xsl:apply-templates/></tt>
</xsl:template>

<xsl:template match="filename">
  <tt><xsl:apply-templates/></tt>
</xsl:template>

<xsl:template match="replaceable">
  <i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template match="screen">
  <pre><xsl:apply-templates mode="fixed"/></pre>
</xsl:template>

<xsl:template match="simplelist">
  <p><xsl:apply-templates select="." mode="formalpara"/></p>
</xsl:template>

<xsl:template match="simplelist" mode="formalpara">
  <xsl:choose>
    <xsl:when test="@type='Inline'">
      <xsl:apply-templates select="member" mode="Inline"/>
    </xsl:when>
    <xsl:when test="@type='Horiz'">
      <xsl:apply-templates select="member" mode="Horiz"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select="member" mode="Vert"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="member" mode="Vert">
  <xsl:apply-templates/><br/>
</xsl:template>

<xsl:template match="member" mode="Inline">
  <xsl:apply-templates/>
  <xsl:if test="following-sibling::member">
    <xsl:text>, </xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template match="informaltable|table">
  <xsl:apply-templates select="tgroup"/>
</xsl:template>

<xsl:template match="thead">
</xsl:template>

<xsl:template match="tgroup">
  <xsl:element name="table">
    <xsl:attribute name="class">
      <xsl:value-of select="name(..)"/>
    </xsl:attribute>
    <xsl:if test="../@frame != '' and ../@frame != 'none'">
      <xsl:attribute name="border">1</xsl:attribute>
    </xsl:if>
    <xsl:if test="../@pgwide = '1'">
      <xsl:attribute name="width">100%</xsl:attribute>
    </xsl:if>
    <xsl:if test="../title">
      <caption class="{name(..)}">
	<b><xsl:apply-templates select="../title"/></b>
      </caption>
    </xsl:if>
    <xsl:apply-templates select="thead"/>
    <xsl:apply-templates select="tbody"/>
  </xsl:element>
</xsl:template>

<xsl:template match="thead">
  <xsl:element name="thead">
    <xsl:apply-templates select="row">
      <xsl:with-param name="td.or.th" select="'th'"/>
    </xsl:apply-templates>
  </xsl:element>
</xsl:template>

<xsl:template match="tbody">
  <xsl:element name="tbody">
    <xsl:apply-templates select="row|anchor"/>
  </xsl:element>
</xsl:template>

<xsl:template match="row">
  <xsl:param name="td.or.th" select="'td'"/>

  <xsl:element name="tr">
    <xsl:if test="../@valign != ''">
      <xsl:attribute name="valign"><xsl:value-of
	select="../@valign"/></xsl:attribute>
    </xsl:if>
    <xsl:if test="../../@align != ''">
      <xsl:attribute name="align"><xsl:value-of
	select="../../@align"/></xsl:attribute>
    </xsl:if>
    <xsl:call-template name="place-anchor"/>
    <xsl:apply-templates select="entry">
      <xsl:with-param name="td.or.th" select="$td.or.th"/>
    </xsl:apply-templates>
  </xsl:element>
</xsl:template>

<xsl:template match="entry">
  <xsl:param name="td.or.th" select="'tr'"/>

  <xsl:element name="{$td.or.th}">
    <xsl:attribute name="class">
      <xsl:value-of select="name(../../../..)"/>
    </xsl:attribute>
    <xsl:call-template name="place-anchor"/>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="itemizedlist">
  <xsl:if test="@test">
    <p><b><xsl:value-of select="@test"/></b></p>
  </xsl:if>
  <ul type="{$toc.sect2.ul}"><xsl:apply-templates select="listitem"/></ul>
</xsl:template>

<xsl:template match="orderedlist">
  <ol type="{$toc.sect2.ol}"><xsl:apply-templates select="listitem"/></ol>
</xsl:template>

<xsl:template match="listitem">
  <li><xsl:call-template name="block"/></li>
</xsl:template>

<xsl:template mode="variablelist" match="listitem">
  <xsl:call-template name="block"/>
</xsl:template>

<xsl:template match="emphasis">
  <i><xsl:apply-templates/></i>
</xsl:template>

<xsl:template match="quote"
  >&#x00BB;<xsl:apply-templates/>&#x00AB;</xsl:template>

<xsl:template match="keycombo">
  <xsl:for-each select="keycap">
    <b><xsl:value-of select="."/></b>
    <xsl:if test="count(following-sibling::keycap)">
      <xsl:value-of select="'+'"/>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template match="blockquote">
  <blockquote><xsl:call-template name="block"/></blockquote>
</xsl:template>

<xsl:template match="variablelist">
  <xsl:apply-templates select="varlistentry"/>
</xsl:template>

<!-- HTML 4.0 does not allow <p> inside <dt> -->
<xsl:template match="varlistentry">
  <dl>
    <dt><xsl:apply-templates select="term"/></dt>
    <dd><xsl:apply-templates mode="variablelist" select="listitem"/></dd>
  </dl>
</xsl:template>

<xsl:template match="text()">
  <xsl:if test="string-length(normalize-space(.))">

    <!-- replace leading white space with a single ' ' -->
    <xsl:if test="count(preceding-sibling::node()) and
      string-length(normalize-space(substring(., 1, 1))) = 0
    ">
      <xsl:value-of select="' '"/>
    </xsl:if>

    <xsl:value-of select="normalize-space(.)"/>

    <!-- replace trailing white space with a single ' ' -->
    <xsl:if test="count(following-sibling::node()) and
      string-length(normalize-space(substring(., string-length(.), 1))) = 0
    ">
      <xsl:value-of select="' '"/>
    </xsl:if>

  </xsl:if>
</xsl:template>

</xsl:stylesheet>
