<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns="http://www.w3.org/1999/xhtml"
                version='1.0'
		exclude-result-prefixes="#default"
>

<!-- $Id -->

<!-- Updated 17 November 2003 by David Horton
        Removed functionality that would differentiate between author and
        maintainer.  Previously this feature would prepend the string
        "Author:" or "Maintainer:" to the author's name based on a role
        attribute used with the <author> tag.  This was removed because
        the English-only spelling of "Author:" and "Maintainer:" did not
        work well with documents not written in English.
-->

<!-- Updated 04 July 2003 by Emma Jane Hogbin
	Corrected the xmlns according to Bob Stayton
-->

<!-- Updated 03 July 2003 by Emma Jane Hogbin
	Implemented the following changes:
	* Removed section that added formatting to the <pre> tags. This can
	  be done with style sheets instead.
	* Replaced the <i> element with a <span class="condition"> on the
	  author conditions. This isn't right yet, but it should be a <span>
	  with a class instead of an <i>. The "condition" should be replaced
	  with whatever the DocBook information was, I don't understand XSLT
	  well enough to do this myself.
-->

<!-- Updated 30 June 2003 by David Horton

     Implemented the following changes:
     * Removed all references to 'doc:type=boolean' to fix several
       <xsl:param name="..." select="..."/> entries.
     * Changed comment referencing www.linuxdoc.org to www.tldp.org.
     * Renamed files to tldp*.xsl rather than ldp*.xsl.
     * Enabled support for a linked CSS stylesheet for html output.
       This feature requires that the file 'style.css' be present in
       the same directory as the html pages.  Backward compatibility
       for browsers not supporting CSS should not be a problem as
       those browsers should simply ignore the tag.  For more info
       on CSS stylesheets see: See http://www.w3.org/Style/CSS/
       There should also be a sample 'style.css' included with this
       distribution.
     * Commented out root.filename = index as docbook.xsl seems to
       take care of this.
-->

<!-- Experimental stylesheet by Dan York
     This is an attempt to replicate the customizations done in ldp.dsl
     Each customization in ldp.dsl is listed in the order in which it
     appears (in ldp.dsl) with the corresponding XSLT template or setting
     below it.  Where there is no XSLT code below an item, that particular
     customization of ldp.dsl is not yet supported here.  Some additional
     options and features have been added and are noted as not being in
     ldp.dsl.  The work on this stylesheet began 5 Jul 2001. -->

<!-- Note that this file, 'ldp-html-common.xsl', is NOT intended to be
     called directly.  Instead, you should call either of two stylesheets:
     'ldp-html.xsl' or 'ldp-html-chunk.xsl'.  The former generates a SINGLE
     HTML file, while the latter performs "chunking" to generate MULTIPLE
     HTML files.  Both of those files import the appropriate Norman Walsh
     stylesheet and then import this customization layer. -->


<!-- NOT IN LDP.DSL
     Creates header content in all generated HTML files -->

<xsl:template name="user.head.content">
  <xsl:param name="node" select="."/>
  <meta name="generator" content="Experimental LDP.XSL $Revision: 1.4 $"/>
  <xsl:text>
  </xsl:text>
  <xsl:comment> Generated by LDP XSLT customization layer
      based on Norman Walsh's DocBook XSL stylesheets.
      More information at http://www.tldp.org/ </xsl:comment>
  <xsl:text>
  </xsl:text>

</xsl:template>

<!-- Create a link to a CSS stylesheet named 'style.css' in all html
     output so that pages can be beautified.  Browsers not supporting
     CSS should safely ignore the link. -->
<xsl:param name="html.stylesheet" select="'style.css'"/>

<!-- declare-characteristic preserve-sdata?
     No longer appears necessary as it is a JadeTex issue. -->

<!-- generate-legalnotice-link? 
     Not currently supported in Norm's XSL stylesheets. Logged
     at SourceForge as a bug. -->

<!-- Should graphics be used for admonitions (notes, warnings)? 0 or 1 -->
<xsl:param name="admon.graphics" select="0"/>

<!-- If using admon graphics (1 above), what is path to graphics? 
     Should be the path relative to your document and MUST end with
     a trailing slash.  Also, this parameter needs to be on a 
     single line. -->
<xsl:param name="admon.graphics.path">images/</xsl:param>

<!-- Note: the default extension for graphics is .png unless the
     following line is uncommented and .ext is replaced with the 
     desired extension. -->
<!-- <xsl:param name="graphic.default.extension" select="'.ext'"/> -->

<!-- Make funcsynopsis look pretty -->
<xsl:param name="funcsynopsis.decoration" select="1"/>

<!-- Extension for HTML files -->
<xsl:param name="html.ext" select="'.html'"/>

<!-- Generate TOCs for book, article, part -->
<xsl:param name="generate.book.toc" select="1"/>
<xsl:param name="generate.article.toc" select="1"/>
<xsl:param name="generate.part.toc" select="1"/>

<!-- generate-book-titlepage -->

<!-- generate-article-titlepage -->

<!-- Equivalent to chunk-skip-first-element-list - forces TOC on separate page 
     If 0, first sect is on page for chapter or article -->
<xsl:param name="chunk.first.sections" select="'1'"/>


<!-- NOT IN LDP.DSL -->
<!-- Create chunks for top-level sections. If 0, chunks will only be
     created for chapters/appendixes, and NOT for sectx elements -->
<!--
not supported
<xsl:param name="chunk.sections" select="'1'"/>
-->

<!-- list-element-list - NO LONGER NEEDED - bug fix -->

<!-- Filename for the root chunk - Not needed, docbook.xsl handles this. -->
<!-- <xsl:param name="root.filename" select="'index'"/> -->

<!-- Shade Verbatim Sections such as programlisting and screen -->
<!-- There is a parameter for this called "shade.verbatim", but better
     results can be obtained using the CSS stylesheet -->

<!-- When chunking, use id attribute as filename? 0 or 1 -->
<xsl:param name="use.id.as.filename" select="1"/>

<!-- Should chapters be labeled? 0 or 1 -->
<xsl:param name="chapter.autolabel" select="1"/>

<!-- Should sections be labeled? 0 or 1 -->
<xsl:param name="section.autolabel" select="1"/>

<!-- Related to section labels, should those labels include the chapter
     number in them (i.e., 1.1, 1.2, 1.3, 1.4 )-->
<xsl:param name="section.label.includes.component.label" select="1"/>

<!-- To what depth (in sections) should the TOC go? -->
<xsl:param name="toc.section.depth" select="2"/>

<!-- Custom 'emphasis' template to allow 'role="strong"' to 
     also produce a bold item. -->
<xsl:template match="emphasis">
  <xsl:choose>
    <xsl:when test="(@role='strong') or (@role='bold')">
      <xsl:call-template name="inline.boldseq"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="inline.italicseq"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- book-titlepage-recto-elements
     article-titlepage-recto-elements 
     article-titlepage-recto-mode 
     article-title 
     
     - Customizing these elements (for instance, to list what is on the
       title page) involves writing a layer for html/titlepage.templates.xml and the
       other files html/titlepage.xsl and html/titlepage.templates.xsl - Norm
       is doing something funky here and I haven't fully figured it out. -->


<!-- NOT IN LDP.DSL. Format Q and A labels. 
     Added by dcm 2003-05-19. -->

<xsl:template match="question" mode="label.markup">
  <xsl:text>Q</xsl:text>
</xsl:template>

<xsl:template match="answer" mode="label.markup">
  <xsl:text>A</xsl:text>
</xsl:template>

</xsl:stylesheet>
